@@ -24,6 +24,7 @@
 
   CHANGE HISTORY:
 
+    24 December 2016 -- by Jean-Romain Roussel -- L51 changed && by || to enable compiling with clang++ on Linux
     20 December 2016 -- by Jean-Romain Roussel -- Change fprint(stderr, ...), raise an exeption
 
     see corresponding header file
@@ -37,7 +38,13 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
+
+#if defined(__clang__)
+  #include <string>
+#else
+  #include <string.h>
+#endif
+
 #include <assert.h>
 #include <stdexcept>
 
@@ -47,7 +54,7 @@ using namespace std;
 
 #ifdef UNORDERED
   // Check if on OS X and using cland (unordered map isn't part of tr1 namespace)
-  #if defined(__APPLE__) && defined(__clang__)
+  #if defined(__APPLE__) || defined(__clang__)
     #include <unordered_map>
   #else
     #include <tr1/unordered_map>
