@@ -44,6 +44,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdexcept>
+#include <Rcpp.h>
 
 LASzip::LASzip()
 {
@@ -436,7 +437,7 @@ bool LASzip::setup(U16* num_items, LASitem** items, const U8 point_type, const U
 //    char error[64];
 //    sprintf(error, "point size %d too small for point type %d by %d bytes", point_size, point_type, -extra_bytes_number);
 //    return return_error(error);
-    throw std::runtime_error(std::string("WARNING: point size %d too small by %d bytes for point type %d. assuming point_size of %d")); //point_size, -extra_bytes_number, point_type, point_size-extra_bytes_number
+    Rcpp::Rcerr << "WARNING: Point size " << point_size << " too small by " << -extra_bytes_number << " bytes for point type " << (int)point_type << " assuming point_size of " << point_size-extra_bytes_number << std::endl; //point_size, -extra_bytes_number, point_type, point_size-extra_bytes_number
     extra_bytes_number = 0;
   }
 
